==> civicrm-6.3.1-standalone.tar.gz: civicrm-standalone/core/release-notes/5.71.2.md <==
# CiviCRM 5.71.2

Released March 28, 2024

- **[Synopsis](#synopsis)**
- **[Bugs resolved](#bugs)**
- **[Credits](#credits)**
- **[Feedback](#feedback)**

## <a name="synopsis"></a>Synopsis

| *Does this version...?*                                         |          |
| --------------------------------------------------------------- | -------- |
| Change the database schema?                                     | no       |
| Alter the API?                                                  | no       |
| Require attention to configuration options?                     | no       |
| Fix problems installing or upgrading to a previous version?     | no       |
| Introduce features?                                             | no       |
| **Fix bugs?**                                                   | **yes**  |
| Fix security vulnerabilities?                                   | no       |

## <a name="bugs"></a>Bugs resolved

* **_CiviContribute_: When submitting an "Other Amount", the amount is split into units of $1 ([dev/core#5079](https://lab.civicrm.org/dev/core/-/issues/5079), [dev/core#5100](https://lab.civicrm.org/dev/core/-/issues/5100): [#29717](https://github.com/civicrm/civicrm-core/pull/29717))**
* **_CiviEvent_: Email receipt does not show transaction number ([dev/core#5088](https://lab.civicrm.org/dev/core/-/issues/5088): [#29715](https://github.com/civicrm/civicrm-core/pull/29715))**
* **_Custom Data_: Multi-select field does not show current values ([dev/core#5090](https://lab.civicrm.org/dev/core/-/issues/5090): [#29721](https://github.com/civicrm/civicrm-core/pull/29721))**
* **_Form Builder_: Page title doesn't display ([#29694](https://github.com/civicrm/civicrm-core/pull/29694))**

## <a name="credits"></a>Credits

This release was developed by the following authors and reviewers:

Wikimedia Foundation - Eileen McNaughton; Third Sector Design - William Mortada, Kurund
Jalmi; Megaphone Technology Consulting - Jon Goldberg; JMA Consulting - Seamus Lee;
civiservice.de - Detlev Sieber; CiviCRM - Coleman Watts

## <a name="feedback"></a>Feedback

These release notes are edited by Tim Otten and Andie Hunt.  If you'd like to
provide feedback on them, please login to https://chat.civicrm.org/civicrm and
contact `@agh1`.

==> civicrm-6.6.2-standalone.tar.gz: civicrm-standalone/core/release-notes/5.71.1.md <==
# CiviCRM 5.71.1

Released March 8, 2024

- **[Synopsis](#synopsis)**
- **[Bugs resolved](#bugs)**
- **[Credits](#credits)**
- **[Feedback](#feedback)**

## <a name="synopsis"></a>Synopsis

| *Does this version...?*                                         |          |
| --------------------------------------------------------------- | -------- |
| Change the database schema?                                     | no       |
| Alter the API?                                                  | no       |
| Require attention to configuration options?                     | no       |
| Fix problems installing or upgrading to a previous version?     | no       |
| Introduce features?                                             | no       |
| **Fix bugs?**                                                   | **yes**  |
| Fix security vulnerabilities?                                   | no       |

## <a name="bugs"></a>Bugs resolved

* **_CiviContribute_: Emails with monetary tokens sometimes fail to render ([#29654](https://github.com/civicrm/civicrm-core/pull/29654))**
* **_CiviMember_: Some "Price Set" configurations involving checkboxes lead to PHP error ([dev/core#5071](https://lab.civicrm.org/dev/core/-/issues/5071): [#29653](https://github.com/civicrm/civicrm-core/pull/29653))**
* **_CiviSurvey_: Error displaying results ("Return type declaration") ([#29658](https://github.com/civicrm/civicrm-core/pull/29658))**

## <a name="credits"></a>Credits

This release was developed by the following authors and reviewers:

Wikimedia Foundation - Eileen McNaughton; CiviCRM - Coleman Watts; Agileware - Francis
Whittle, Agileware Team

## <a name="feedback"></a>Feedback

These release notes are edited by Tim Otten and Andie Hunt.  If you'd like to
provide feedback on them, please login to https://chat.civicrm.org/civicrm and
contact `@agh1`.
